==> beast-web-2.3-20200811.083103-9-sources.jar: com/xunyi/beast/web/converter/json/JacksonCustomAutoConfiguration.java <==
package com.xunyi.beast.web.converter.json;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.DeserializationFeature;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.SerializationFeature;
import com.xunyi.beast.data.message.jackson.MessageModule;
import com.xunyi.beast.data.money.jackson.MoneyModule;
import com.xunyi.beast.data.mongo.MongoModule;
import com.xunyi.beast.data.page.PageSerializer;
import org.springframework.boot.autoconfigure.AutoConfigureBefore;
import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnClass;
import org.springframework.boot.autoconfigure.jackson.Jackson2ObjectMapperBuilderCustomizer;
import org.springframework.boot.autoconfigure.jackson.JacksonAutoConfiguration;
import org.springframework.context.MessageSource;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.data.domain.Page;
import org.springframework.data.mongodb.core.MongoOperations;
import org.springframework.http.converter.json.Jackson2ObjectMapperBuilder;


/**
 * 可以实现自定义序列化Bean, JsonComponentModule会加载
 *
 * @see JacksonAutoConfiguration
 */
@Configuration
@ConditionalOnClass(ObjectMapper.class)
@AutoConfigureBefore(JacksonAutoConfiguration.class)
public class JacksonCustomAutoConfiguration {

    @Configuration
    @ConditionalOnClass(Jackson2ObjectMapperBuilder.class)
    static class JacksonCustomizerConfiguration {
        @Bean
        public Jackson2ObjectMapperBuilderCustomizer jackson2ObjectMapperBuilderCustomizer() {
            return jacksonObjectMapperBuilder -> {
                jacksonObjectMapperBuilder.serializationInclusion(JsonInclude.Include.NON_NULL);
                jacksonObjectMapperBuilder.featuresToEnable(SerializationFeature.WRITE_DATES_AS_TIMESTAMPS);
                jacksonObjectMapperBuilder.featuresToDisable(SerializationFeature.WRITE_DATE_TIMESTAMPS_AS_NANOSECONDS);
                jacksonObjectMapperBuilder.featuresToDisable(DeserializationFeature.READ_DATE_TIMESTAMPS_AS_NANOSECONDS);
            };
        }

        @ConditionalOnClass(Page.class)
        @Bean
        public Jackson2ObjectMapperBuilderCustomizer pageJackson2ObjectMapperBuilderCustomizer() {
            return jacksonObjectMapperBuilder -> {
                jacksonObjectMapperBuilder.serializers(new PageSerializer());
            };
        }

        @Bean
        @ConditionalOnBean(MessageSource.class)
        public MessageModule messageModule(MessageSource source) {
            return new MessageModule(source);
        }

        @Bean
        @ConditionalOnBean(MongoOperations.class)
        public MongoModule mongoModule() {
            return new MongoModule();
        }

        @Bean
        public MoneyModule moneyModule() {
            return new MoneyModule();
        }
    }

}

==> beast-web-2.3-20200819.100900-26-sources.jar: com/xunyi/beast/web/converter/json/JacksonCustomAutoConfiguration.java <==
package com.xunyi.beast.web.converter.json;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.DeserializationFeature;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.SerializationFeature;
import com.xunyi.beast.data.message.ErrorMessageSource;
import com.xunyi.beast.data.message.jackson.MessageModule;
import com.xunyi.beast.data.money.jackson.MoneyModule;
import com.xunyi.beast.data.mongo.MongoModule;
import com.xunyi.beast.data.page.PageSerializer;
import org.springframework.boot.autoconfigure.AutoConfigureBefore;
import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnClass;
import org.springframework.boot.autoconfigure.jackson.Jackson2ObjectMapperBuilderCustomizer;
import org.springframework.boot.autoconfigure.jackson.JacksonAutoConfiguration;
import org.springframework.context.MessageSource;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.data.domain.Page;
import org.springframework.data.mongodb.core.MongoOperations;
import org.springframework.http.converter.json.Jackson2ObjectMapperBuilder;


/**
 * 可以实现自定义序列化Bean, JsonComponentModule会加载
 *
 * @see JacksonAutoConfiguration
 */
@Configuration(proxyBeanMethods = false)
@ConditionalOnClass(ObjectMapper.class)
@AutoConfigureBefore(JacksonAutoConfiguration.class)
public class JacksonCustomAutoConfiguration {

    @Configuration
    @ConditionalOnClass(Jackson2ObjectMapperBuilder.class)
    static class JacksonCustomizerConfiguration {
        @Bean
        public Jackson2ObjectMapperBuilderCustomizer jackson2ObjectMapperBuilderCustomizer() {
            return jacksonObjectMapperBuilder -> {
                jacksonObjectMapperBuilder.serializationInclusion(JsonInclude.Include.NON_NULL);
                jacksonObjectMapperBuilder.featuresToEnable(SerializationFeature.WRITE_DATES_AS_TIMESTAMPS);
                jacksonObjectMapperBuilder.featuresToDisable(SerializationFeature.WRITE_DATE_TIMESTAMPS_AS_NANOSECONDS);
                jacksonObjectMapperBuilder.featuresToDisable(DeserializationFeature.READ_DATE_TIMESTAMPS_AS_NANOSECONDS);
            };
        }

        @ConditionalOnClass(Page.class)
        @Bean
        public Jackson2ObjectMapperBuilderCustomizer pageJackson2ObjectMapperBuilderCustomizer() {
            return jacksonObjectMapperBuilder -> {
                jacksonObjectMapperBuilder.serializers(new PageSerializer());
            };
        }

        @Bean
        @ConditionalOnBean(ErrorMessageSource.class)
        public MessageModule messageModule(ErrorMessageSource source) {
            return new MessageModule(source);
        }

        @Bean
        @ConditionalOnBean(MongoOperations.class)
        public MongoModule mongoModule() {
            return new MongoModule();
        }

        @Bean
        public MoneyModule moneyModule() {
            return new MoneyModule();
        }
    }

}
